@@ -488,7 +488,7 @@ Creating tmp file.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Number of grade 0 cards to learn at once:</source>
+        <source>Number of grade 0 cards to hold in your hand:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -1355,7 +1355,7 @@ Happy learning!</source>
 <context>
     <name>StatisticsDlg</name>
     <message>
-        <source>Scheduled cards for the next days:
+        <source>Scheduled cards for next week:
 
 </source>
         <translation type="unfinished"></translation>
